@@ -48,8 +48,7 @@ struct UpDeviceIdevicePrivate
 	lockdownd_client_t	 client;
 };
 
-G_DEFINE_TYPE (UpDeviceIdevice, up_device_idevice, UP_TYPE_DEVICE)
-#define UP_DEVICE_IDEVICE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), UP_TYPE_DEVICE_IDEVICE, UpDeviceIdevicePrivate))
+G_DEFINE_TYPE_WITH_PRIVATE (UpDeviceIdevice, up_device_idevice, UP_TYPE_DEVICE)
 
 static gboolean		 up_device_idevice_refresh		(UpDevice *device);
 
@@ -347,7 +346,7 @@ out:
 static void
 up_device_idevice_init (UpDeviceIdevice *idevice)
 {
-	idevice->priv = UP_DEVICE_IDEVICE_GET_PRIVATE (idevice);
+	idevice->priv = up_device_idevice_get_instance_private (idevice);
 }
 
 /**
@@ -390,8 +389,6 @@ up_device_idevice_class_init (UpDeviceIdeviceClass *klass)
 	object_class->finalize = up_device_idevice_finalize;
 	device_class->coldplug = up_device_idevice_coldplug;
 	device_class->refresh = up_device_idevice_refresh;
-
-	g_type_class_add_private (klass, sizeof (UpDeviceIdevicePrivate));
 }
 
 /**
