@@ -33,8 +33,6 @@
 
 static void	up_history_finalize	(GObject		*object);
 
-#define UP_HISTORY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), UP_TYPE_HISTORY, UpHistoryPrivate))
-
 #define UP_HISTORY_FILE_HEADER		"PackageKit Profile"
 #define UP_HISTORY_SAVE_INTERVAL	(10*60)		/* seconds */
 #define UP_HISTORY_DEFAULT_MAX_DATA_AGE	(7*24*60*60)	/* seconds */
@@ -61,7 +59,7 @@ enum {
 	UP_HISTORY_LAST_SIGNAL
 };
 
-G_DEFINE_TYPE (UpHistory, up_history, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (UpHistory, up_history, G_TYPE_OBJECT)
 
 /**
  * up_history_set_max_data_age:
@@ -874,7 +872,6 @@ up_history_class_init (UpHistoryClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	object_class->finalize = up_history_finalize;
-	g_type_class_add_private (klass, sizeof (UpHistoryPrivate));
 }
 
 /**
@@ -884,7 +881,7 @@ up_history_class_init (UpHistoryClass *klass)
 static void
 up_history_init (UpHistory *history)
 {
-	history->priv = UP_HISTORY_GET_PRIVATE (history);
+	history->priv = up_history_get_instance_private (history);
 	history->priv->data_rate = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
 	history->priv->data_charge = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
 	history->priv->data_time_full = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
